''' A tiny secret manager written in python'''
__version__="0.0.2"
from .secretm import *
